from enum import Enum


class Geraetetyp(str, Enum):
    """
    Auflistung möglicher abzurechnender Gerätetypen.
    """

    WECHSELSTROMZAEHLER = "WECHSELSTROMZAEHLER"
    DREHSTROMZAEHLER = "DREHSTROMZAEHLER"
    ZWEIRICHTUNGSZAEHLER = "ZWEIRICHTUNGSZAEHLER"
    RLM_ZAEHLER = "RLM_ZAEHLER"
    BALGENGASZAEHLER = "BALGENGASZAEHLER"
    MAXIMUMZAEHLER = "MAXIMUMZAEHLER"
    MULTIPLEXANLAGE = "MULTIPLEXANLAGE"
    PAUSCHALANLAGE = "PAUSCHALANLAGE"
    VERSTAERKERANLAGE = "VERSTAERKERANLAGE"
    SUMMATIONSGERAET = "SUMMATIONSGERAET"
    IMPULSGEBER = "IMPULSGEBER"
    EDL_21_ZAEHLERAUFSATZ = "EDL_21_ZAEHLERAUFSATZ"
    VIER_QUADRANTEN_LASTGANGZAEHLER = "VIER_QUADRANTEN_LASTGANGZAEHLER"
    MENGENUMWERTER = "MENGENUMWERTER"
    STROMWANDLER = "STROMWANDLER"
    SPANNUNGSWANDLER = "SPANNUNGSWANDLER"
    KOMBIMESSWANDLER = "KOMBIMESSWANDLER"
    BLOCKSTROMWANDLER = "BLOCKSTROMWANDLER"
    DATENLOGGER = "DATENLOGGER"
    KOMMUNIKATIONSANSCHLUSS = "KOMMUNIKATIONSANSCHLUSS"
    MODEM = "MODEM"
    TELEKOMMUNIKATIONSEINRICHTUNG = "TELEKOMMUNIKATIONSEINRICHTUNG"
    DREHKOLBENGASZAEHLER = "DREHKOLBENGASZAEHLER"
    TURBINENRADGASZAEHLER = "TURBINENRADGASZAEHLER"
    ULTRASCHALLZAEHLER = "ULTRASCHALLZAEHLER"
    WIRBELGASZAEHLER = "WIRBELGASZAEHLER"
    MODERNE_MESSEINRICHTUNG = "MODERNE_MESSEINRICHTUNG"
    INTELLIGENTES_MESSYSTEM = "INTELLIGENTES_MESSYSTEM"
    ELEKTRONISCHER_HAUSHALTSZAEHLER = "ELEKTRONISCHER_HAUSHALTSZAEHLER"
    STEUEREINRICHTUNG = "STEUEREINRICHTUNG"
    TARIFSCHALTGERAET = "TARIFSCHALTGERAET"
    RUNDSTEUEREMPFAENGER = "RUNDSTEUEREMPFAENGER"
    OPTIONALE_ZUS_ZAEHLEINRICHTUNG = "OPTIONALE_ZUS_ZAEHLEINRICHTUNG"
    MESSWANDLERSATZ_IMS_MME = "MESSWANDLERSATZ_IMS_MME"
    KOMBIMESSWANDLER_IMS_MME = "KOMBIMESSWANDLER_IMS_MME"
    TARIFSCHALTGERAET_IMS_MME = "TARIFSCHALTGERAET_IMS_MME"
    RUNDSTEUEREMPFAENGER_IMS_MME = "RUNDSTEUEREMPFAENGER_IMS_MME"
    TEMPERATUR_KOMPENSATION = "TEMPERATUR_KOMPENSATION"
    HOECHSTBELASTUNGS_ANZEIGER = "HOECHSTBELASTUNGS_ANZEIGER"
    SONSTIGES_GERAET = "SONSTIGES_GERAET"
    PREPAYMENTZAEHLER = "PREPAYMENTZAEHLER"
    EDL_21 = "EDL_21"
    FIELD_96_H_ZAEHLER = "96_H_ZAEHLER"
    EDL_40_ZAEHLERAUFSATZ = "EDL_40_ZAEHLERAUFSATZ"
    EDL_40 = "EDL_40"
