from enum import Enum


class Zaehlertyp(str, Enum):
    """
    Bei diesem Enum handelt es sich um die Abbildung von Zählertypen der Sparten Strom und Gas.
    """

    DREHSTROMZAEHLER = "DREHSTROMZAEHLER"
    BALGENGASZAEHLER = "BALGENGASZAEHLER"
    DREHKOLBENZAEHLER = "DREHKOLBENZAEHLER"
    SMARTMETER = "SMARTMETER"
    LEISTUNGSZAEHLER = "LEISTUNGSZAEHLER"
    MAXIMUMZAEHLER = "MAXIMUMZAEHLER"
    TURBINENRADGASZAEHLER = "TURBINENRADGASZAEHLER"
    ULTRASCHALLGASZAEHLER = "ULTRASCHALLGASZAEHLER"
    WECHSELSTROMZAEHLER = "WECHSELSTROMZAEHLER"
    WIRBELGASZAEHLER = "WIRBELGASZAEHLER"
    MESSDATENREGISTRIERGERAET = "MESSDATENREGISTRIERGERAET"
    ELEKTRONISCHERHAUSHALTSZAEHLER = "ELEKTRONISCHERHAUSHALTSZAEHLER"
    SONDERAUSSTATTUNG = "SONDERAUSSTATTUNG"
    MODERNEMESSEINRICHTUNG = "MODERNEMESSEINRICHTUNG"
    LASTGANGZAEHLER = "LASTGANGZAEHLER"
    NEUEMESSEINRICHTUNG = "NEUEMESSEINRICHTUNG"
