from enum import Enum


class Leistungstyp(str, Enum):
    ARBEITSPREIS_WIRKARBEIT = "ARBEITSPREIS_WIRKARBEIT"
    LEISTUNGSPREIS_WIRKLEISTUNG = "LEISTUNGSPREIS_WIRKLEISTUNG"
    ARBEITSPREIS_BLINDARBEIT_IND = "ARBEITSPREIS_BLINDARBEIT_IND"
    ARBEITSPREIS_BLINDARBEIT_KAP = "ARBEITSPREIS_BLINDARBEIT_KAP"
    GRUNDPREIS = "GRUNDPREIS"
    GRUNDPREIS_ARBEIT = "GRUNDPREIS_ARBEIT"
    GRUNDPREIS_LEISTUNG = "GRUNDPREIS_LEISTUNG"
    MEHRMINDERMENGE = "MEHRMINDERMENGE"
    MESSSTELLENBETRIEB = "MESSSTELLENBETRIEB"
    MESSDIENSTLEISTUNG = "MESSDIENSTLEISTUNG"
    MESSDIENSTLEISTUNG_INKL_MESSUNG = "MESSDIENSTLEISTUNG_INKL_MESSUNG"
    ABRECHNUNG = "ABRECHNUNG"
    KONZESSIONS_ABGABE = "KONZESSIONS_ABGABE"
    KWK_UMLAGE = "KWK_UMLAGE"
    OFFSHORE_UMLAGE = "OFFSHORE_UMLAGE"
    ABLAV_UMLAGE = "ABLAV_UMLAGE"
    SONDERKUNDEN_UMLAGE = "SONDERKUNDEN_UMLAGE"
    REGELENERGIE_UMLAGE = "REGELENERGIE_UMLAGE"
    BILANZIERUNG_UMLAGE = "BILANZIERUNG_UMLAGE"
    AUSLESUNG_ZUSAETZLICH = "AUSLESUNG_ZUSAETZLICH"
    ABLESUNG_ZUSAETZLICH = "ABLESUNG_ZUSAETZLICH"
    ABRECHNUNG_ZUSAETZLICH = "ABRECHNUNG_ZUSAETZLICH"
    SPERRUNG = "SPERRUNG"
    ENTSPERRUNG = "ENTSPERRUNG"
    MAHNKOSTEN = "MAHNKOSTEN"
    INKASSOKOSTEN = "INKASSOKOSTEN"
    EEG_UMLAGE = "EEG_UMLAGE"
    ENERGIESTEUER = "ENERGIESTEUER"
    NETZPREIS = "NETZPREIS"
    MESSPREIS = "MESSPREIS"
    SONSTIGER_PREIS = "SONSTIGER_PREIS"
    DIENSTLEISTUNG = "DIENSTLEISTUNG"
