from enum import Enum


class Geraetemerkmal(str, Enum):
    """
    Auflistung möglicher abzurechnender Gerätetypen.
    """

    EINTARIF = "EINTARIF"
    ZWEITARIF = "ZWEITARIF"
    MEHRTARIF = "MEHRTARIF"
    GAS_G2_5 = "GAS_G2_5"
    GAS_G4 = "GAS_G4"
    GAS_G6 = "GAS_G6"
    GAS_G10 = "GAS_G10"
    GAS_G16 = "GAS_G16"
    GAS_G25 = "GAS_G25"
    GAS_G40 = "GAS_G40"
    GAS_G65 = "GAS_G65"
    GAS_G100 = "GAS_G100"
    GAS_G160 = "GAS_G160"
    GAS_G250 = "GAS_G250"
    GAS_G400 = "GAS_G400"
    GAS_G650 = "GAS_G650"
    GAS_G1000 = "GAS_G1000"
    GAS_G1600 = "GAS_G1600"
    GAS_G2500 = "GAS_G2500"
    IMPULSGEBER_G4_G100 = "IMPULSGEBER_G4_G100"
    IMPULSGEBER_G100 = "IMPULSGEBER_G100"
    TELEFONANSCHLUSS = "TELEFONANSCHLUSS"
    MODEM_GSM = "MODEM_GSM"
    MODEM_GPRS = "MODEM_GPRS"
    MODEM_FUNK = "MODEM_FUNK"
    MODEM_GSM_O_LG = "MODEM_GSM_O_LG"
    MODEM_GSM_M_LG = "MODEM_GSM_M_LG"
    MODEM_FESTNETZ = "MODEM_FESTNETZ"
    MODEM_GPRS_M_LG = "MODEM_GPRS_M_LG"
    PLC_KOM = "PLC_KOM"
    ETHERNET_KOM = "ETHERNET_KOM"
    DSL_KOM = "DSL_KOM"
    LTE_KOM = "LTE_KOM"
    KOMPAKT_MU = "KOMPAKT_MU"
    SYSTEM_MU = "SYSTEM_MU"
    TEMPERATUR_MU = "TEMPERATUR_MU"
    ZUSTANDS_MU = "ZUSTANDS_MU"
    UNBESTIMMT = "UNBESTIMMT"
