from enum import Enum


class Voraussetzungen(str, Enum):
    """
    Voraussetzungen, die erfüllt sein müssen, damit dieser Tarif zur Anwendung kommen kann.
    """

    EINZUGSERMAECHTIGUNG = "EINZUGSERMAECHTIGUNG"
    ZEITPUNKT = "ZEITPUNKT"
    LIEFERANBINDUNG_EINE = "LIEFERANBINDUNG_EINE"
    LIEFERANBINDUNG_ALLE = "LIEFERANBINDUNG_ALLE"
    GEWERBE = "GEWERBE"
    LASTPROFIL = "LASTPROFIL"
    ZAEHLERTYP_GROESSE = "ZAEHLERTYP_GROESSE"
    AUSSCHLUSS_GROSSVERBRAUCHER = "AUSSCHLUSS_GROSSVERBRAUCHER"
    NEUKUNDE = "NEUKUNDE"
    BESTIMMTE_VERTRAGSFORMALITAETEN = "BESTIMMTE_VERTRAGSFORMALITAETEN"
    SELBSTABLESUNG = "SELBSTABLESUNG"
    ONLINEVORAUSSETZUNG = "ONLINEVORAUSSETZUNG"
    MINDESTUMSATZ = "MINDESTUMSATZ"
    ZUSATZPRODUKT = "ZUSATZPRODUKT"
    NEUKUNDE_MIT_VORAUSSETZUNGEN = "NEUKUNDE_MIT_VORAUSSETZUNGEN"
    DIREKTVERTRIEB = "DIREKTVERTRIEB"
    ANSCHLUSSART = "ANSCHLUSSART"
    ANSCHLUSSWERT = "ANSCHLUSSWERT"
    ALTER_KUNDENANLAGE = "ALTER_KUNDENANLAGE"
    ANLAGEBESCHAFFENHEIT = "ANLAGEBESCHAFFENHEIT"
    BETRIEBSSTUNDENBEGRENZUNG = "BETRIEBSSTUNDENBEGRENZUNG"
    FREIGABEZEITEN = "FREIGABEZEITEN"
    FAMILIENSTRUKTUR = "FAMILIENSTRUKTUR"
    MITGLIEDSCHAFT = "MITGLIEDSCHAFT"
    STAATLICHE_FOERDERUNG = "STAATLICHE_FOERDERUNG"
    BESONDERE_VERBRAUCHSSTELLE = "BESONDERE_VERBRAUCHSSTELLE"
    NIEDRIGENERGIE = "NIEDRIGENERGIE"
    ORTSTEILE_LIEFERGEBIET = "ORTSTEILE_LIEFERGEBIET"
    WAERMEBEDARF_ERDGAS = "WAERMEBEDARF_ERDGAS"
    MAX_ZAEHLER_LIEFERSTELLEN = "MAX_ZAEHLER_LIEFERSTELLEN"
    LIEFERUNGSBESCHRAENKUNG_GASART = "LIEFERUNGSBESCHRAENKUNG_GASART"
    KOMBI_BONI = "KOMBI_BONI"
    ALTVERTRAG = "ALTVERTRAG"
    VORGESCHRIEBENE_ZUSATZANLAGE = "VORGESCHRIEBENE_ZUSATZANLAGE"
    MEHRERE_ZAEHLER_ABNAHMESTELLEN = "MEHRERE_ZAEHLER_ABNAHMESTELLEN"
    BESTIMMTER_ABNAHMEFALL = "BESTIMMTER_ABNAHMEFALL"
    ZUSATZMODALITAET = "ZUSATZMODALITAET"
    NACHWEIS_ZAHLUNGSFAEHIGKEIT = "NACHWEIS_ZAHLUNGSFAEHIGKEIT"
    UMSTELLUNG_ENERGIEART = "UMSTELLUNG_ENERGIEART"
